#!/bin/sh
## simple test of DVI file inclusion in EPS file generated by METAPOST
tex storyx
dvitomp storyx.dvi storyx.mpx
## it is advisable to avoid quotes -- hence the `str' operation:
mpost "\vardef ifi = str storyx.mpx enddef; vardef ofi = str storyx.mpy enddef; input fix_brks.mp"
mpost test-bop.mp
tex test-bop.tex
dvips test-bop.dvi -o test-bop.ps
## CLEAN:
rm storyx.dvi
rm storyx.log
# rm storyx.mpx
# rm storyx.mpy
rm test-bop.dvi
rm test-bop.log
rm test-bop.10*

